@@ -1,15 +1,13 @@
 from functools import wraps
 import logging
 
-from .gif import GIF
-from .two_d_plots import two_d_time_series
-from .three_d_plots import three_d_scatter_rotate
+from plotly_gif.gif import GIF
+from plotly_gif.two_d_plots import two_d_time_series
+from plotly_gif.three_d_plots import three_d_scatter_rotate
 
 __all__ = ["GIF", "capture", "two_d_time_series", "three_d_scatter_rotate"]
 
-
-level = logging.INFO
-logging.basicConfig(level=level, format='  %(message)s')
+logging.basicConfig(level=logging.INFO, format='  %(message)s')
 
 
 def capture(gif_: GIF):
